==> haskell-fast-logger-3.0.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 3.0.0
id: fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
key: fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A fast logging system
description:
    A fast logging system
category: System
abi: d1ed2aee7c599a3cf5a4204caae6cc05
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Types
hidden-modules: System.Log.FastLogger.Imports
                System.Log.FastLogger.IO System.Log.FastLogger.FileIO
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-3.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fast-logger-3.0.0
hs-libraries: HSfast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
depends:
    array-0.5.3.0 auto-update-0.1.6-6HwoHb0UkWSDuW69IvZChU
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    easy-file-0.2.2-49v0RQkxTQF1Wq1oAMulzs filepath-1.4.2.1
    text-1.2.3.1 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unix-time-0.4.7-6BQqpN4x0rZGemgLOEGe7v
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-3.0.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 3.0.0
id: fast-logger-3.0.0-5U3SuuA3S8r8Dz8F0S9pSI
key: fast-logger-3.0.0-5U3SuuA3S8r8Dz8F0S9pSI
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A fast logging system
description:
    A fast logging system
category: System
abi: 5af521bd742eb07f99fa5e5fa76b8fd5
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Types
hidden-modules: System.Log.FastLogger.Imports
                System.Log.FastLogger.IO System.Log.FastLogger.FileIO
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-3.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fast-logger-3.0.0
hs-libraries: HSfast-logger-3.0.0-5U3SuuA3S8r8Dz8F0S9pSI
depends:
    array-0.5.3.0 auto-update-0.1.6-AD4rZqZjPpq5MsqX4q4CPr
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    easy-file-0.2.2-49v0RQkxTQF1Wq1oAMulzs filepath-1.4.2.1
    text-1.2.3.1 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unix-time-0.4.7-6BQqpN4x0rZGemgLOEGe7v
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
